/**
 *  Copyright (c) 2010-2012, The StaccatoCommons Team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; version 3 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 */

/////////////////////////////////////////////////
///// WARNING: GENERATE CODE. DO NOT EDIT ///////
/////////////////////////////////////////////////

package net.sf.staccatocommons.util.apache;

import net.sf.staccatocommons.defs.NullSafe;
import net.sf.staccatocommons.defs.function.Function;
import net.sf.staccatocommons.defs.predicate.Predicate;
import net.sf.staccatocommons.lang.function.internal.TopLevelFunction;
import net.sf.staccatocommons.lang.predicate.internal.TopLevelPredicate;

import org.apache.commons.lang.StringUtils;

/***
 * {@link Function}s and {@link Predicate}s based on Apache {@link StringUtils}. 
 * They provide a 1-1 mapping to that utility class. 
 */
public final class Strings {


  /**
   * @see StringUtils#length(String)
   */
  @NullSafe
  public static Function<String, Integer> length() {
    class ApacheLengthFunction extends TopLevelFunction<String, Integer> {
      private static final long serialVersionUID = 1L;
      public Integer apply(String arg) {
        return StringUtils.length(arg);
      }
    }
    return new ApacheLengthFunction();
  }


  /**
   * @see StringUtils#isEmpty(String)
   */
  @NullSafe
  public static Predicate<String> isEmpty() {
    class ApacheIsEmptyPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isEmpty(arg);
      }
    }
    return new ApacheIsEmptyPredicate();
  }


  /**
   * @see StringUtils#split(String)
   */
  @NullSafe
  public static Function<String, String[]> split() {
    class ApacheSplitFunction extends TopLevelFunction<String, String[]> {
      private static final long serialVersionUID = 1L;
      public String[] apply(String arg) {
        return StringUtils.split(arg);
      }
    }
    return new ApacheSplitFunction();
  }


  /**
   * @see StringUtils#trim(String)
   */
  @NullSafe
  public static Function<String, String> trim() {
    class ApacheTrimFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.trim(arg);
      }
    }
    return new ApacheTrimFunction();
  }


  /**
   * @see StringUtils#reverse(String)
   */
  @NullSafe
  public static Function<String, String> reverse() {
    class ApacheReverseFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.reverse(arg);
      }
    }
    return new ApacheReverseFunction();
  }


  /**
   * @see StringUtils#isWhitespace(String)
   */
  @NullSafe
  public static Predicate<String> isWhitespace() {
    class ApacheIsWhitespacePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isWhitespace(arg);
      }
    }
    return new ApacheIsWhitespacePredicate();
  }


  /**
   * @see StringUtils#clean(String)
   */
  @NullSafe
  public static Function<String, String> clean() {
    class ApacheCleanFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.clean(arg);
      }
    }
    return new ApacheCleanFunction();
  }


  /**
   * @see StringUtils#escape(String)
   */
  @NullSafe
  public static Function<String, String> escape() {
    class ApacheEscapeFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.escape(arg);
      }
    }
    return new ApacheEscapeFunction();
  }


  /**
   * @see StringUtils#isAlpha(String)
   */
  @NullSafe
  public static Predicate<String> isAlpha() {
    class ApacheIsAlphaPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAlpha(arg);
      }
    }
    return new ApacheIsAlphaPredicate();
  }


  /**
   * @see StringUtils#isNotEmpty(String)
   */
  @NullSafe
  public static Predicate<String> isNotEmpty() {
    class ApacheIsNotEmptyPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isNotEmpty(arg);
      }
    }
    return new ApacheIsNotEmptyPredicate();
  }


  /**
   * @see StringUtils#deleteWhitespace(String)
   */
  @NullSafe
  public static Function<String, String> deleteWhitespace() {
    class ApacheDeleteWhitespaceFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.deleteWhitespace(arg);
      }
    }
    return new ApacheDeleteWhitespaceFunction();
  }


  /**
   * @see StringUtils#isBlank(String)
   */
  @NullSafe
  public static Predicate<String> isBlank() {
    class ApacheIsBlankPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isBlank(arg);
      }
    }
    return new ApacheIsBlankPredicate();
  }


  /**
   * @see StringUtils#isNotBlank(String)
   */
  @NullSafe
  public static Predicate<String> isNotBlank() {
    class ApacheIsNotBlankPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isNotBlank(arg);
      }
    }
    return new ApacheIsNotBlankPredicate();
  }


  /**
   * @see StringUtils#chomp(String)
   */
  @NullSafe
  public static Function<String, String> chomp() {
    class ApacheChompFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.chomp(arg);
      }
    }
    return new ApacheChompFunction();
  }


  /**
   * @see StringUtils#chompLast(String)
   */
  @NullSafe
  public static Function<String, String> chompLast() {
    class ApacheChompLastFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.chompLast(arg);
      }
    }
    return new ApacheChompLastFunction();
  }


  /**
   * @see StringUtils#chop(String)
   */
  @NullSafe
  public static Function<String, String> chop() {
    class ApacheChopFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.chop(arg);
      }
    }
    return new ApacheChopFunction();
  }


  /**
   * @see StringUtils#chopNewline(String)
   */
  @NullSafe
  public static Function<String, String> chopNewline() {
    class ApacheChopNewlineFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.chopNewline(arg);
      }
    }
    return new ApacheChopNewlineFunction();
  }


  /**
   * @see StringUtils#strip(String)
   */
  @NullSafe
  public static Function<String, String> strip() {
    class ApacheStripFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.strip(arg);
      }
    }
    return new ApacheStripFunction();
  }


  /**
   * @see StringUtils#upperCase(String)
   */
  @NullSafe
  public static Function<String, String> upperCase() {
    class ApacheUpperCaseFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.upperCase(arg);
      }
    }
    return new ApacheUpperCaseFunction();
  }


  /**
   * @see StringUtils#lowerCase(String)
   */
  @NullSafe
  public static Function<String, String> lowerCase() {
    class ApacheLowerCaseFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.lowerCase(arg);
      }
    }
    return new ApacheLowerCaseFunction();
  }


  /**
   * @see StringUtils#uncapitalise(String)
   */
  @NullSafe
  public static Function<String, String> uncapitalise() {
    class ApacheUncapitaliseFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.uncapitalise(arg);
      }
    }
    return new ApacheUncapitaliseFunction();
  }


  /**
   * @see StringUtils#capitalise(String)
   */
  @NullSafe
  public static Function<String, String> capitalise() {
    class ApacheCapitaliseFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.capitalise(arg);
      }
    }
    return new ApacheCapitaliseFunction();
  }


  /**
   * @see StringUtils#swapCase(String)
   */
  @NullSafe
  public static Function<String, String> swapCase() {
    class ApacheSwapCaseFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.swapCase(arg);
      }
    }
    return new ApacheSwapCaseFunction();
  }


  /**
   * @see StringUtils#capitaliseAllWords(String)
   */
  @NullSafe
  public static Function<String, String> capitaliseAllWords() {
    class ApacheCapitaliseAllWordsFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.capitaliseAllWords(arg);
      }
    }
    return new ApacheCapitaliseAllWordsFunction();
  }


  /**
   * @see StringUtils#isAlphaSpace(String)
   */
  @NullSafe
  public static Predicate<String> isAlphaSpace() {
    class ApacheIsAlphaSpacePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAlphaSpace(arg);
      }
    }
    return new ApacheIsAlphaSpacePredicate();
  }


  /**
   * @see StringUtils#isAlphanumeric(String)
   */
  @NullSafe
  public static Predicate<String> isAlphanumeric() {
    class ApacheIsAlphanumericPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAlphanumeric(arg);
      }
    }
    return new ApacheIsAlphanumericPredicate();
  }


  /**
   * @see StringUtils#isAlphanumericSpace(String)
   */
  @NullSafe
  public static Predicate<String> isAlphanumericSpace() {
    class ApacheIsAlphanumericSpacePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAlphanumericSpace(arg);
      }
    }
    return new ApacheIsAlphanumericSpacePredicate();
  }


  /**
   * @see StringUtils#isNumeric(String)
   */
  @NullSafe
  public static Predicate<String> isNumeric() {
    class ApacheIsNumericPredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isNumeric(arg);
      }
    }
    return new ApacheIsNumericPredicate();
  }


  /**
   * @see StringUtils#isNumericSpace(String)
   */
  @NullSafe
  public static Predicate<String> isNumericSpace() {
    class ApacheIsNumericSpacePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isNumericSpace(arg);
      }
    }
    return new ApacheIsNumericSpacePredicate();
  }


  /**
   * @see StringUtils#defaultString(String)
   */
  @NullSafe
  public static Function<String, String> defaultString() {
    class ApacheDefaultStringFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.defaultString(arg);
      }
    }
    return new ApacheDefaultStringFunction();
  }


  /**
   * @see StringUtils#capitalize(String)
   */
  @NullSafe
  public static Function<String, String> capitalize() {
    class ApacheCapitalizeFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.capitalize(arg);
      }
    }
    return new ApacheCapitalizeFunction();
  }


  /**
   * @see StringUtils#isAsciiPrintable(String)
   */
  @NullSafe
  public static Predicate<String> isAsciiPrintable() {
    class ApacheIsAsciiPrintablePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAsciiPrintable(arg);
      }
    }
    return new ApacheIsAsciiPrintablePredicate();
  }


  /**
   * @see StringUtils#trimToNull(String)
   */
  @NullSafe
  public static Function<String, String> trimToNull() {
    class ApacheTrimToNullFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.trimToNull(arg);
      }
    }
    return new ApacheTrimToNullFunction();
  }


  /**
   * @see StringUtils#trimToEmpty(String)
   */
  @NullSafe
  public static Function<String, String> trimToEmpty() {
    class ApacheTrimToEmptyFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.trimToEmpty(arg);
      }
    }
    return new ApacheTrimToEmptyFunction();
  }


  /**
   * @see StringUtils#stripToNull(String)
   */
  @NullSafe
  public static Function<String, String> stripToNull() {
    class ApacheStripToNullFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.stripToNull(arg);
      }
    }
    return new ApacheStripToNullFunction();
  }


  /**
   * @see StringUtils#stripToEmpty(String)
   */
  @NullSafe
  public static Function<String, String> stripToEmpty() {
    class ApacheStripToEmptyFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.stripToEmpty(arg);
      }
    }
    return new ApacheStripToEmptyFunction();
  }


  /**
   * @see StringUtils#splitPreserveAllTokens(String)
   */
  @NullSafe
  public static Function<String, String[]> splitPreserveAllTokens() {
    class ApacheSplitPreserveAllTokensFunction extends TopLevelFunction<String, String[]> {
      private static final long serialVersionUID = 1L;
      public String[] apply(String arg) {
        return StringUtils.splitPreserveAllTokens(arg);
      }
    }
    return new ApacheSplitPreserveAllTokensFunction();
  }


  /**
   * @see StringUtils#splitByCharacterType(String)
   */
  @NullSafe
  public static Function<String, String[]> splitByCharacterType() {
    class ApacheSplitByCharacterTypeFunction extends TopLevelFunction<String, String[]> {
      private static final long serialVersionUID = 1L;
      public String[] apply(String arg) {
        return StringUtils.splitByCharacterType(arg);
      }
    }
    return new ApacheSplitByCharacterTypeFunction();
  }


  /**
   * @see StringUtils#splitByCharacterTypeCamelCase(String)
   */
  @NullSafe
  public static Function<String, String[]> splitByCharacterTypeCamelCase() {
    class ApacheSplitByCharacterTypeCamelCaseFunction extends TopLevelFunction<String, String[]> {
      private static final long serialVersionUID = 1L;
      public String[] apply(String arg) {
        return StringUtils.splitByCharacterTypeCamelCase(arg);
      }
    }
    return new ApacheSplitByCharacterTypeCamelCaseFunction();
  }


  /**
   * @see StringUtils#deleteSpaces(String)
   */
  @NullSafe
  public static Function<String, String> deleteSpaces() {
    class ApacheDeleteSpacesFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.deleteSpaces(arg);
      }
    }
    return new ApacheDeleteSpacesFunction();
  }


  /**
   * @see StringUtils#uncapitalize(String)
   */
  @NullSafe
  public static Function<String, String> uncapitalize() {
    class ApacheUncapitalizeFunction extends TopLevelFunction<String, String> {
      private static final long serialVersionUID = 1L;
      public String apply(String arg) {
        return StringUtils.uncapitalize(arg);
      }
    }
    return new ApacheUncapitalizeFunction();
  }


  /**
   * @see StringUtils#isAllLowerCase(String)
   */
  @NullSafe
  public static Predicate<String> isAllLowerCase() {
    class ApacheIsAllLowerCasePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAllLowerCase(arg);
      }
    }
    return new ApacheIsAllLowerCasePredicate();
  }


  /**
   * @see StringUtils#isAllUpperCase(String)
   */
  @NullSafe
  public static Predicate<String> isAllUpperCase() {
    class ApacheIsAllUpperCasePredicate extends TopLevelPredicate<String> {
      private static final long serialVersionUID = 1L;

      public boolean eval(String arg) {
        return StringUtils.isAllUpperCase(arg);
      }
    }
    return new ApacheIsAllUpperCasePredicate();
  }
 
}
